==> php83-nextcloud-26.0.5.tgz: share/nextcloud/apps/password_policy/l10n/cs.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Platnost hesla skončila – nastavte si nové prostřednictvím procedury pro zapomenuté heslo",
    "Password must not have been used recently before." : "Je třeba, aby heslo nebylo některé z těch, které jste používali nedávno.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Heslo spadá mezi 1 000 000 nejčastějších (a tím útočníkům nejsnáze prolomitelných). Vytvořte si nějaké neobvyklé a tím bezpečnější.",
    "Password is present in compromised password list. Please choose a different password." : "Heslo se nachází na seznamu kompromitovaných hesel. Zvolte jiné.",
    "Password needs to be at least %s characters long." : "Je třeba, aby heslo bylo alespoň %s znaků dlouhé.",
    "Password needs to contain at least one numeric character." : "Je třeba, aby heslo obsahovalo alespoň jednu číslici.",
    "Password needs to contain at least one special character." : "Je třeba, aby heslo obsahovalo alespoň jeden speciální znak.",
    "Password needs to contain at least one lower and one upper case character." : "Je třeba, aby heslo obsahovalo alespoň jedno malé a jedno velké písmeno.",
    "Password policy" : "Požadavky na hesla",
    "Allows admins to configure a password policy" : "Umožňuje správcům nastavovat pravidla pro hesla",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Umožnit správci definovat určité požadavky na heslo – např. vynutit minimální délku",
    "Minimum password length" : "Minimální délka hesla",
    "User password history" : "Historie hesel uživatele",
    "Number of days until user password expires" : "Počet dní do skončení platnosti hesla uživatele",
    "Number of login attempts before the user account is blocked (0 for no limit)" : "Počet pokusů o přihlášení před zablokováním uživatelského účtu (0 bez omezení)",
    "Forbid common passwords" : "Zakázat běžná hesla",
    "Enforce upper and lower case characters" : "Vyžadovat VELKÁ a malá písmena",
    "Enforce numeric characters" : "Vyžadovat čísla",
    "Enforce special characters" : "Vyžadovat speciální znaky",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Zkontrolovat heslo vůči seznamu prolomených hesel na haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Tato kontrola vytvoří otisk (hash) hesla a pošle prvních 5 znaků tohoto otisku na aplikační program. rozhraní (API) služby haveibeenpwned.com pro získání seznamu všech otisků, které začínají na tento. Pak zkontroluje na instanci Nextcloud, zda se ve výsledné sadě vyskytuje otisk daného hesla.",
    "Unknown error" : "Neznámá chyba",
    "Minimal length has to be a non negative number" : "Je třeba, aby nejkratší přípustná délka nebylo záporné číslo",
    "History size has to be a non negative number" : "Je třeba, aby hloubka historie nebylo záporné číslo",
    "Expiration days have to be a non negative number" : "Je třeba, aby počet dnů do skončení platnosti nebylo záporné číslo",
    "Maximum login attempts have to be a non negative number" : "Je třeba, aby nejvyšší umožněný počet pokusů o přihlášení nebylo záporné číslo",
    "Settings saved" : "Nastavení uložena",
    "Error while saving settings" : "Chyba při ukládání nastavení",
    "Saved" : "Uloženo",
    "Error while saving" : "Chyba při ukládání"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");

==> php83-nextcloud-29.0.8.tgz: share/nextcloud/apps/password_policy/l10n/cs.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Platnost hesla skončila – nastavte si nové prostřednictvím procedury pro zapomenuté heslo",
    "Password must not have been used recently before." : "Je třeba, aby heslo nebylo některé z těch, které jste používali nedávno.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Heslo spadá mezi 1 000 000 nejčastějších (a tím útočníkům nejsnáze prolomitelných). Vytvořte si nějaké neobvyklé a tím bezpečnější.",
    "Password is present in compromised password list. Please choose a different password." : "Heslo se nachází na seznamu kompromitovaných hesel. Zvolte jiné.",
    "Password needs to be at least %s characters long." : "Je třeba, aby heslo bylo alespoň %s znaků dlouhé.",
    "Password needs to contain at least one numeric character." : "Je třeba, aby heslo obsahovalo alespoň jednu číslici.",
    "Password needs to contain at least one special character." : "Je třeba, aby heslo obsahovalo alespoň jeden speciální znak.",
    "Password needs to contain at least one lower and one upper case character." : "Je třeba, aby heslo obsahovalo alespoň jedno malé a jedno velké písmeno.",
    "Password policy" : "Požadavky na hesla",
    "Allows admins to configure a password policy" : "Umožňuje správcům nastavovat pravidla pro hesla",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Umožnit správci definovat určité požadavky na heslo – např. vynutit minimální délku",
    "Minimum password length" : "Minimální délka hesla",
    "User password history" : "Historie hesel uživatele",
    "Number of days until user password expires" : "Počet dní do skončení platnosti hesla uživatele",
    "Number of login attempts before the user account will be disabled until manual action is taken. (0 for no limit)" : "Počet pokusů o přihlášení před zablokováním uživatelského účtu (0 bez omezení)",
    "Please note, this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "Toto nastavení je určeno k ochraně napadených účtů. Zablokované účty je nutné manuálně zapnout v administraci. Útočníkům snažícím se uhádnout hesla uživatelských účtů bude jejich IP adresa zablokována nezávisle na tomto nastavení.",
    "Forbid common passwords" : "Zakázat běžná hesla",
    "Enforce upper and lower case characters" : "Vyžadovat VELKÁ a malá písmena",
    "Enforce numeric characters" : "Vyžadovat čísla",
    "Enforce special characters" : "Vyžadovat speciální znaky",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Zkontrolovat heslo vůči seznamu prolomených hesel na haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Tato kontrola vytvoří otisk (hash) hesla a pošle prvních 5 znaků tohoto otisku na aplikační program. rozhraní (API) služby haveibeenpwned.com pro získání seznamu všech otisků, které začínají na tento. Pak zkontroluje na instanci Nextcloud, zda se ve výsledné sadě vyskytuje otisk daného hesla.",
    "Unknown error" : "Neznámá chyba",
    "Minimal length has to be a non negative number" : "Je třeba, aby nejkratší přípustná délka nebylo záporné číslo",
    "History size has to be a non negative number" : "Je třeba, aby hloubka historie nebylo záporné číslo",
    "Expiration days have to be a non negative number" : "Je třeba, aby počet dnů do skončení platnosti nebylo záporné číslo",
    "Maximum login attempts have to be a non negative number" : "Je třeba, aby nejvyšší umožněný počet pokusů o přihlášení nebylo záporné číslo",
    "Settings saved" : "Nastavení uložena",
    "Error while saving settings" : "Chyba při ukládání nastavení",
    "Please note, that this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "Mějte na paměti, že toto nastavení je určeno k ochraně napadených účtů. Zablokované účty je nutné manuálně zapnout v administraci. Útočníkům snažícím se uhádnout hesla uživatelských účtů bude jejich IP adresa zablokována nezávisle na tomto nastavení."
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
